@@ -1,5 +1,8 @@
 #!/usr/bin/perl
 
+eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
+    if 0; # not running under some shell
+
 eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
     if 0; # not running under some shell
 
@@ -29,8 +32,8 @@ use warnings;
 BEGIN {
 
    my $edit=0;my $earg='';my $cnt=-1;
-   my $VERSION=0;my $version=0;
-   our $planarg=0;our $cronarg=0;
+   my $VERSION=0;my $version=0;my $welcome=0;
+   our $planarg=0;our $cronarg=0;my $admin=0;
    foreach my $arg (@ARGV) {
       if ($arg=~/^--ed*i*t*$/) {
          $edit=1;
@@ -48,10 +51,16 @@ BEGIN {
       } elsif ($arg=~/^-[a-df-uw-zA-Z]*v/ ||
                $arg=~/^--VE*R*S*I*O*N*$/) {
          $version=1;
+      } elsif ($arg=~/^--about$/) {
+         $version=1;
       } elsif ($arg=~/^--plan$/) {
          $planarg=1;
       } elsif ($arg=~/^--cron$/) {
          $cronarg=1;
+      } elsif ($arg=~/^--welcome$/) {
+         $welcome=1;
+      } elsif ($arg=~/^--admin$/) {
+         $admin=1; 
       }
       $cnt++;
    }
@@ -67,6 +76,14 @@ BEGIN {
       require Net::FullAuto::FA_Core;
       &Net::FullAuto::FA_Core::version();
       exit;
+   } elsif ($welcome) {
+      require Net::FullAuto::FA_Core;
+      &Net::FullAuto::FA_Core::welcome();
+      exit;
+   } elsif ($admin) {
+      require Net::FullAuto::FA_Core;
+      $Net::FullAuto::FA_Core::admin_menu->();
+      exit;
    }
 
    # our $fa_custom_code='fa_code.pm';
